'''
 NAME:                simple_plot_7_python

 DESCRIPTION:         Plots data read from several files.
                     Uses different line styles and colors
                      Labels datapoints

 EXECUTION COMMAND:
                      > python simple_plot_7_python.py

 INPUTS:              File cigale_fit.txt
		     		   File m82_match.txt
                      File arp220_match.txt
                      File rr_fit.txt
                      File observed_fluxes.txt

 OUTPUTS:             PDF file: python_plot.pdf

 NOTES:               change the input data. 
                      change the output PDF name.


 AUTHOR:              Alex VIANA
                      Space Telescope Science Institute, USA 
 
 REVISION HISTORY:
                      Written by Alex VIANA, NOV 2012. 

'''


# ------------------------ python code begins here

#!/usr/bin/env python

import numpy as np
import matplotlib
import matplotlib.pyplot as plt

flux_cigale = np.genfromtxt('cigale_fit.txt', comments=';', 
			names = ['lambda_cigale', 'flux_cigale'])
flux_m82 = np.genfromtxt('m82_match.txt', comments=';', 
			names = ['lambda_m82', 'flux_m82'])
flux_arp = np.genfromtxt('arp220_match.txt', comments=';', 
			names = ['lambda_arp', 'flux_arp'])
flux_rr = np.genfromtxt('rr_fit.txt', comments=';', 
			names = ['lambda_rr', 'flux_rr'])
flux_data = np.genfromtxt('observed_fluxes.txt', comments=';', 
			names = ['lambda_data', 'flux_data', 'flux_error_data'])

# Create the figure and axes instances.
# Adjust the plot to the right so the y axes label fits.
fig, ax1 = plt.subplots(figsize = (4.7, 6.3))
plt.subplots_adjust(left = 0.25, right = 0.99)

# Plot the CIGALE line with a specially defined line style.
ax1.plot(flux_cigale['lambda_cigale'], flux_cigale['flux_cigale'],'r', 
		label = 'CIGALE')
line = ax1.plot(flux_m82['lambda_m82'], flux_m82['flux_m82'], 'b-.', 
		label = 'M82')
seq = [2, 4, 2, 4, 2, 4, 7, 4]
line[0].set_dashes(seq)

# Plot the other lines. Remove the flux from the legend. 
ax1.plot(flux_arp['lambda_arp'], flux_arp['flux_arp'], color='orange', 
		linestyle='-.', label = 'Arp220')
ax1.plot(flux_rr['lambda_rr'], flux_rr['flux_rr'], 'g--', 
		label = 'Rowan-Robinson')
ax1.plot(flux_data['lambda_data'], flux_data['flux_data'], 'b.', 
		label = '_nolegend_')

#Plot the error bars on the flux.
ax1.errorbar(flux_data['lambda_data'], flux_data['flux_data'], 
			yerr = flux_data['flux_error_data'])

# Limits, scale, legend, and labels.
ax1.set_xscale('log')
ax1.set_yscale('log')
ax1.set_xlim(0.2, 5500)
ax1.set_ylim(0.001, 1000)
leg = ax1.legend(fancybox=True, loc = 'upper left')
leg.draw_frame(False)
ax1.set_xlabel('Wavelength [$\mu$m]')
ax1.set_ylabel('Flux desnisty [mJy]')

# Turn off scientific notation on the axes.
y_formatter = matplotlib.ticker.ScalarFormatter(useOffset=False)
ax1.yaxis.set_major_formatter(y_formatter)
ax1.xaxis.set_major_formatter(y_formatter)

# Save the figure as a pdf.
fig.savefig('python_plot.pdf', papertype='letter')

# ------------------------ python code ends here

